@@ -2,7 +2,7 @@
 
 # SOCI (as of November 2020, SOCI v4 has still not been released on Debian/Ubuntu)
 
-SOCI_VER="4.0.1"
+SOCI_VER="4.0.2"
 SOCI_DIR="/opt/soci"
 
 if [ "$1" != "" ]
@@ -26,12 +26,14 @@ echo
 mkdir ${SOCI_DIR}/archives
 echo
 echo "Downloading SOCI v${SOCI_VER} into ${SOCI_DIR}"
-wget https://github.com/SOCI/soci/archive/${SOCI_VER}.tar.gz -O ${SOCI_DIR}/archives/soci-${SOCI_VER}.tar.gz
+rm -f ${SOCI_DIR}/archives/soci-${SOCI_VER}.tar.gz
+wget https://github.com/SOCI/soci/archive/v${SOCI_VER}.tar.gz -O ${SOCI_DIR}/archives/soci-${SOCI_VER}.tar.gz
 
 # Unpack SOCI
 pushd ${SOCI_DIR}
 echo
 echo "Unpacking SOCI v${SOCI_VER} into ${SOCI_DIR}"
+rm -rf soci-${SOCI_VER}
 tar zxf archives/soci-${SOCI_VER}.tar.gz
 pushd soci-${SOCI_VER}
 patch -p1 < ../soci-debian-cmake.patch
