@@ -6,12 +6,13 @@ import json
 import pyopentrep, Travel_pb2
 
 # Initialise the OpenTrep C++ library
-  porPath = f"{trep_dir}/share/opentrep/data/por/test_optd_por_public.csv"
+trep_dir = "/var/www/webapps/opentrep/trep"
+porPath = f"{trep_dir}/share/opentrep/data/por/test_optd_por_public.csv"
 # xapianDBPath = "/tmp/opentrep/xapian_traveldb"
 # sqlDBConnStr = "/tmp/opentrep/sqlite_travel.db"
-xapianDBPath = "/var/www/webapps/opentrep/trep/traveldb"
+xapianDBPath = f"{trep_dir}/traveldb"
 sqlDBType = "sqlite"
-sqlDBConnStr = "/var/www/webapps/opentrep/trep/sqlite_travel.db"
+sqlDBConnStr = f"{trep_dir}/sqlite_travel.db"
 #sqlDBType = "mysql"
 #sqlDBConnStr = "db=trep_trep user=trep password=trep"
 deploymentNb = 0
@@ -20,7 +21,6 @@ flagIndexPORInXapian = True
 flagAddPORInDB = True
 logPath = "/var/log/webapps/search/pyopentrep.log"
 openTrepLibrary = pyopentrep.OpenTrepSearcher()
-#queryAnswer = Travel_pb2.QueryAnswer()
 initOK = openTrepLibrary.init (porPath, xapianDBPath, sqlDBType, sqlDBConnStr,
                                deploymentNb,
                                flagDontIndexIATAPOR, flagIndexPORInXapian,
